pub struct RunErrorEvent {
pub base: BaseEvent,
pub message: String,
pub code: Option<String>,
}Expand description
Event indicating that a run has encountered an error.
This event is sent when an agent run fails with an error.
Fields
base: BaseEventCommon event fields (timestamp, rawEvent).
message: StringError message describing what went wrong.
code: Option<String>Optional error code for programmatic handling.
Implementations
Sourceimpl RunErrorEvent
impl RunErrorEvent
Sourcepub fn new(message: impl Into<String>) -> RunErrorEvent
pub fn new(message: impl Into<String>) -> RunErrorEvent
Creates a new RunErrorEvent.
Sourcepub fn with_code(self, code: impl Into<String>) -> RunErrorEvent
pub fn with_code(self, code: impl Into<String>) -> RunErrorEvent
Sets the error code.
Sourcepub fn with_timestamp(self, timestamp: f64) -> RunErrorEvent
pub fn with_timestamp(self, timestamp: f64) -> RunErrorEvent
Sets the timestamp for this event.