pub struct StateDeltaEvent {
pub base: BaseEvent,
pub delta: Vec<Value>,
}Expand description
Event containing incremental state updates as JSON Patch operations.
This event is sent to update state incrementally using RFC 6902 JSON Patch format. The delta is a vector of patch operations (add, remove, replace, move, copy, test).
Fields
base: BaseEventCommon event fields (timestamp, rawEvent).
delta: Vec<Value>JSON Patch operations per RFC 6902.
Implementations
Sourceimpl StateDeltaEvent
impl StateDeltaEvent
Sourcepub fn new(delta: Vec<Value>) -> StateDeltaEvent
pub fn new(delta: Vec<Value>) -> StateDeltaEvent
Creates a new StateDeltaEvent with the given patch operations.
Sourcepub fn with_timestamp(self, timestamp: f64) -> StateDeltaEvent
pub fn with_timestamp(self, timestamp: f64) -> StateDeltaEvent
Sets the timestamp for this event.