pub struct ToolCall {
pub id: ToolCallId,
pub call_type: String,
pub function: FunctionCall,
}Expand description
A tool call made by an assistant.
Represents a specific invocation of a tool/function by the model, including the tool call ID, type, and function details.
Fields
id: ToolCallIdUnique identifier for this tool call.
call_type: StringThe type of call (always “function” for now).
function: FunctionCallThe function being called with its arguments.
Implementations
Sourceimpl ToolCall
impl ToolCall
Sourcepub fn new(id: impl Into<ToolCallId>, function: FunctionCall) -> ToolCall
pub fn new(id: impl Into<ToolCallId>, function: FunctionCall) -> ToolCall
Creates a new tool call with the given ID and function.